import typer

from terrafy.commands.authenticate import authenticate
from terrafy.commands.create import create
from terrafy.commands.docs import docs

app = typer.Typer()

app.command()(docs)
app.command()(authenticate)
app.command()(create)


def main():
    app()
